@@ -11,9 +11,7 @@ utils::globalVariables(c(".", ":="))
 
 .onAttach <- function(lib, pkg){
   message <- paste0(
-    sprintf("gtfs2gps version %s is now loaded\n",utils::packageDescription("gtfs2gps")$Version),
-    "NOTE: All filter functions from gtfs2gps were removed\n",
-    "Please replace them by similar functions from gtfstools")
+    sprintf("gtfs2gps version %s is now loaded\n",utils::packageDescription("gtfs2gps")$Version))
 
   packageStartupMessage(message)
 }
